agent

package
v0.0.0-...-ac72dc2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 23, 2026 License: AGPL-3.0 Imports: 19 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func HostPublicKey

func HostPublicKey() string

HostPublicKey exposes the public host key for writing known_hosts entries.

Types

type Agent

type Agent struct {
	// contains filtered or unexported fields
}

Agent implements the runtime for the agent process.

func New

func New(cfg AgentConfig) *Agent

func (*Agent) Start

func (a *Agent) Start(ctx context.Context) error

Start blocks until fatal error or context cancellation.

type AgentConfig

type AgentConfig struct {
	HubURL    string
	Token     string
	AgentName string
	LocalPort int

	// SkipSSHD when true skips starting the embedded sshd server.
	// The agent will connect to an existing SSH server on LocalPort.
	SkipSSHD bool

	Timeouts common.Timeouts
}

AgentConfig holds runtime settings for the agent process.

Jump to