Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func HostPublicKey ¶
func HostPublicKey() string
HostPublicKey exposes the public host key for writing known_hosts entries.
Types ¶
type Agent ¶
type Agent struct {
// contains filtered or unexported fields
}
Agent implements the runtime for the agent process.
func New ¶
func New(cfg AgentConfig) *Agent
type AgentConfig ¶
type AgentConfig struct {
HubURL string
Token string
AgentName string
LocalPort int
// SkipSSHD when true skips starting the embedded sshd server.
// The agent will connect to an existing SSH server on LocalPort.
SkipSSHD bool
Timeouts common.Timeouts
}
AgentConfig holds runtime settings for the agent process.
Click to show internal directories.
Click to hide internal directories.